IsCompatible

Trait IsCompatible 

pub trait IsCompatible {
    type Out;
}
Boolean type operator for Stack compatibility.

If shapes T and U may be stacked, then the Out associated type of this trait for (T, U) is True. Otherwise, it is False`.

Required Associated Types

Implementations on Foreign Types

Source

impl<T, U> IsCompatible for (TensorShape<T>, TensorShape<U>)

Implementors